==> shu-c-utils-1.0.15.tgz: package/src/utils/helper.js <==
import _endsWith from 'lodash/endsWith';
import _includes from 'lodash/includes';
import _isNil from 'lodash/isNil';
import _forEach from 'lodash/forEach';
import _toNumber from 'lodash/toNumber';

const isVoid = value => value === undefined || value === null || value === '';

// 去除对象中value为空(null,undefined,'')的属性

/* let res=cleanObject({
  name:'',
  pageSize:10,
  page:1
})
console.log("res", res) //输入{ page: 1, pageSize: 10 }
 */
const cleanObject = object => {
  // Object.assign({}, object)
  if (!object) {
    return {};
  }
  const result = { ...object };
  Object.keys(result).forEach(key => {
    const value = result[key];
    if (isVoid(value)) {
      delete result[key];
    }
  });
  return result;
};

// 跟进区域code返回得到 地区层级 1-省 2-市 3-县
const getAdCodeToLevel = areaCode => {
  let areaType = '';
  if (_endsWith(areaCode, '0000')) {
    areaType = 1; // 省
  }
  if (_endsWith(areaCode, '00') && !_includes(areaCode, '0000')) {
    areaType = 2; // 市
  }
  if (!areaCode.match(/([0])$/g)) {
    areaType = 3; // 区
  }
  return areaType;
};

// echarts 图表px尺寸大小跟进当前屏幕大小转换
const echartsPxToRem = function(res, viewWidth = 1920) {
  const clientWidth =
    window.innerWidth ||
    document.documentElement.clientWidth ||
    document.body.clientWidth;
  if (!clientWidth) return;
  const fontSize = clientWidth / viewWidth;
  return res * fontSize;
};

// start和end 转换 区间描述
const startAndEnd2describe = function({
  data,
  endMsg = '大于',
  startMsg = '小于',
  endNumKey = 'endNum',
  startNumKey = 'startNum',
  icon = '-'
}) {
  const endNum = data[endNumKey];
  const startNum = data[startNumKey];
  if (!_isNil(endNum) && _isNil(startNum)) {
    return `${startMsg}${data.endNum}`;
  }
  if (!_isNil(startNum) && _isNil(endNum)) {
    return `${endMsg}${data.startNum}`;
  }
  return `${startNum}${icon}${endNum}`;
};

// 获取具体value对应的区间内的对象
const getIntervalValueObj = function({
  aIntervalList,
  value,
  endNumKey = 'endNum',
  startNumKey = 'startNum'
}) {
  let condition = null;
  _forEach(aIntervalList, dkptCondition => {
    const endNum = dkptCondition[endNumKey];
    const startNum = dkptCondition[startNumKey];
    if (!_isNil(endNum) && _isNil(startNum) && value < _toNumber(endNum)) {
      // 小于最小值
      condition = dkptCondition;
    }
    if (!_isNil(startNum) && _isNil(endNum) && value >= _toNumber(startNum)) {
      // 大于最大值
      condition = dkptCondition;
    }
    if (
      !_isNil(startNum) &&
      !_isNil(endNum) &&
      value >= _toNumber(startNum) &&
      value < _toNumber(endNum)
    ) {
      condition = dkptCondition;
    }
    return null;
  });
  return condition;
};

export {
  cleanObject,
  isVoid,
  getAdCodeToLevel,
  echartsPxToRem,
  startAndEnd2describe,
  getIntervalValueObj
};

==> shu-c-utils-1.0.18.tgz: package/src/utils/helper.js <==
import _endsWith from 'lodash/endsWith';
import _includes from 'lodash/includes';
import _isNil from 'lodash/isNil';
import _forEach from 'lodash/forEach';
import _toNumber from 'lodash/toNumber';

const isVoid = value => value === undefined || value === null || value === '';

// 去除对象中value为空(null,undefined,'')的属性

/* let res=cleanObject({
  name:'',
  pageSize:10,
  page:1
})
console.log("res", res) //输入{ page: 1, pageSize: 10 }
 */
const cleanObject = object => {
  // Object.assign({}, object)
  if (!object) {
    return {};
  }
  const result = { ...object };
  Object.keys(result).forEach(key => {
    const value = result[key];
    if (isVoid(value)) {
      delete result[key];
    }
  });
  return result;
};

// 跟进区域code返回得到 地区层级 1-省 2-市 3-县
const getAdCodeToLevel = areaCode => {
  let areaType = '';
  if (_endsWith(areaCode, '0000')) {
    areaType = 1; // 省
  }
  if (_endsWith(areaCode, '00') && !_includes(areaCode, '0000')) {
    areaType = 2; // 市
  }
  if (!areaCode.match(/([0])$/g)) {
    areaType = 3; // 区
  }
  return areaType;
};

// echarts 图表px尺寸大小跟进当前屏幕大小转换
const echartsResizeToFont = function(res, viewWidth = 1920, zoom = null) {
  const clientWidth =
    window.innerWidth ||
    document.documentElement.clientWidth ||
    document.body.clientWidth;
  if (!clientWidth) return;
  const fontSize = clientWidth / viewWidth;
  if (zoom !== null) {
    // zoom层级大小
    return res * fontSize * Math.sqrt(zoom); // Math.sqrt 求平方根
  }
  return res * fontSize;
};

// start和end 转换 区间描述
const startAndEnd2describe = function({
  data,
  endMsg = '大于',
  startMsg = '小于',
  endNumKey = 'endNum',
  startNumKey = 'startNum',
  icon = '-'
}) {
  const endNum = data[endNumKey];
  const startNum = data[startNumKey];
  if (!_isNil(endNum) && _isNil(startNum)) {
    return `${startMsg}${endNum}`;
  }
  if (!_isNil(startNum) && _isNil(endNum)) {
    return `${endMsg}${startNum}`;
  }
  return `${startNum}${icon}${endNum}`;
};

// 获取具体value对应的区间内的对象
const getIntervalValueObj = function({
  aIntervalList,
  value,
  endNumKey = 'endNum',
  startNumKey = 'startNum'
}) {
  let condition = null;
  _forEach(aIntervalList, dkptCondition => {
    const endNum = dkptCondition[endNumKey];
    const startNum = dkptCondition[startNumKey];
    if (!_isNil(endNum) && _isNil(startNum) && value < _toNumber(endNum)) {
      // 小于最小值
      condition = dkptCondition;
    }
    if (!_isNil(startNum) && _isNil(endNum) && value >= _toNumber(startNum)) {
      // 大于最大值
      condition = dkptCondition;
    }
    if (
      !_isNil(startNum) &&
      !_isNil(endNum) &&
      value >= _toNumber(startNum) &&
      value < _toNumber(endNum)
    ) {
      condition = dkptCondition;
    }
    return null;
  });
  return condition;
};

export {
  cleanObject,
  isVoid,
  getAdCodeToLevel,
  echartsResizeToFont,
  startAndEnd2describe,
  getIntervalValueObj
};
